@@ -2,7 +2,6 @@ package DBIx::Class::Core;
 
 use strict;
 use warnings;
-no warnings 'qw';
 
 use base qw/DBIx::Class/;
 
@@ -12,7 +11,8 @@ __PACKAGE__->load_components(qw/
   PK::Auto
   PK
   Row
-  ResultSourceProxy::Table/);
+  ResultSourceProxy::Table
+/);
 
 1;
 
@@ -22,8 +22,8 @@ DBIx::Class::Core - Core set of DBIx::Class modules
 
 =head1 SYNOPSIS
 
-  # In your table classes
-  __PACKAGE__->load_components(qw/Core/);
+  # In your result (table) classes
+  use base 'DBIx::Class::Core';
 
 =head1 DESCRIPTION
 
@@ -36,7 +36,7 @@ The core modules currently are:
 
 =item L<DBIx::Class::InflateColumn>
 
-=item L<DBIx::Class::Relationship>
+=item L<DBIx::Class::Relationship> (See also L<DBIx::Class::Relationship::Base>)
 
 =item L<DBIx::Class::PK::Auto>
 
@@ -44,7 +44,7 @@ The core modules currently are:
 
 =item L<DBIx::Class::Row>
 
-=item L<DBIx::Class::ResultSourceProxy::Table>
+=item L<DBIx::Class::ResultSourceProxy::Table> (See also L<DBIx::Class::ResultSource>)
 
 =back
 
