@@ -2,12 +2,9 @@ package DBIx::Class::Storage::DBI::ADO::Microsoft_SQL_Server::Cursor;
 
 use strict;
 use warnings;
-
 use base 'DBIx::Class::Storage::DBI::Cursor';
 use mro 'c3';
-
 use DBIx::Class::Storage::DBI::ADO::CursorUtils qw/_normalize_guids _strip_trailing_binary_nulls/;
-use DBIx::Class::ResultSource::FromSpec::Util 'fromspec_columns_info';
 use namespace::clean;
 
 =head1 NAME
@@ -40,69 +37,52 @@ for the inner cursor class.
 
 =cut
 
-sub next {
-  my $self = shift;
+sub _dbh_next {
+  my ($storage, $dbh, $self) = @_;
 
-  my @row = $self->next::method(@_);
+  my $next = $self->next::can;
 
-  $self->{_colinfos} ||= fromspec_columns_info($self->args->[0]);
+  my @row = $next->(@_);
 
-  _normalize_guids(
-    $self->args->[1],
-    $self->{_colinfos},
-    \@row,
-    $self->storage
-  );
+  my $col_infos = $storage->_resolve_column_info($self->args->[0]);
 
-  _strip_trailing_binary_nulls(
-    $self->args->[1],
-    $self->{_colinfos},
-    \@row,
-    $self->storage
-  );
+  my $select = $self->args->[1];
+
+  _normalize_guids($select, $col_infos, \@row, $storage);
+  _strip_trailing_binary_nulls($select, $col_infos, \@row, $storage);
 
   return @row;
 }
 
-sub all {
-  my $self = shift;
+sub _dbh_all {
+  my ($storage, $dbh, $self) = @_;
 
-  my @rows = $self->next::method(@_);
+  my $next = $self->next::can;
 
-  $self->{_colinfos} ||= fromspec_columns_info($self->args->[0]);
+  my @rows = $next->(@_);
+
+  my $col_infos = $storage->_resolve_column_info($self->args->[0]);
+
+  my $select = $self->args->[1];
 
   for (@rows) {
-    _normalize_guids(
-      $self->args->[1],
-      $self->{_colinfos},
-      $_,
-      $self->storage
-    );
-
-    _strip_trailing_binary_nulls(
-      $self->args->[1],
-      $self->{_colinfos},
-      $_,
-      $self->storage
-    );
+    _normalize_guids($select, $col_infos, $_, $storage);
+    _strip_trailing_binary_nulls($select, $col_infos, $_, $storage);
   }
 
   return @rows;
 }
 
-=head1 FURTHER QUESTIONS?
+1;
 
-Check the list of L<additional DBIC resources|DBIx::Class/GETTING HELP/SUPPORT>.
+=head1 AUTHOR
 
-=head1 COPYRIGHT AND LICENSE
+See L<DBIx::Class/AUTHOR> and L<DBIx::Class/CONTRIBUTORS>.
 
-This module is free software L<copyright|DBIx::Class/COPYRIGHT AND LICENSE>
-by the L<DBIx::Class (DBIC) authors|DBIx::Class/AUTHORS>. You can
-redistribute it and/or modify it under the same terms as the
-L<DBIx::Class library|DBIx::Class/COPYRIGHT AND LICENSE>.
+=head1 LICENSE
+
+You may distribute this code under the same terms as Perl itself.
 
 =cut
 
-1;
-
 # vim:sts=2 sw=2:
