@@ -1,5 +1,5 @@
 package DBICTestAdminInc;
-use base 'DBIx::Class::Schema';
+use base 'DBICTest::BaseSchema';
 
 sub connect { exit 70 } # this is what the test will expect to see
 
